
# bedrock-rnd - curated footprints, symbols and devmaps for Ringdove EDA
# Copyright (C) 2025  Tibor 'Igor2' Palinkas
#
# dist-license: GPL2+
# use-license (license of the output): unlimited (CC0 or public domain)
#
# For more information: doc/license.html
#        or on the web: http://www.repo.hu/projects/bedrock-rnd/license.html
#
# Project page: http://www.repo.hu/projects/bedrock-rnd
#

BEGIN {
	gversion="2025-01-20"
	generator = "so-rfp"
	bedrock_ver = "2025-01-08a"
}

BEGIN {
	help_auto()

	proc_args(P, "N,PW,PL,PRP,PP,CPL,CPW,BL,BW,PP,PE,PT,PC,PG,CYE" ipc_params, "N,PW,PL,PRP,PP")

# load args
	load_dim(P["PW"],  "PW")
	load_dim(P["PL"],  "PL")
	load_dim(P["PRP"], "PRP")
	load_dim(P["CPL"],  "CPL")
	load_dim(P["CPW"],  "CPW")
	load_dim(P["BL"],  "BL")
	load_dim(P["BW"],  "BW")
	load_dim(P["PP"],  "PP")
	load_dim(P["PE"],  "PE")
	load_dim(P["PT"],  "PT")
	load_dim(P["PC"],  "PC")
	load_dim(P["PG"],  "PG")

# improvise missing component drawing data
	if (P["CYE"] == "")
		load_rfp("CYE", mm(0.25))
	if (P["PE"] == "")
		load_rfp("PE", round_to(P["PRP"] * 1.1, 0.05))
	if ((P["PC"] == "") && (P["PG"] == "")) {
		load_rfp("PG", P["PRP"] - P["PL"] * 0.8)
		load_rfp("PC", (NOM["PE"] - NOM["PG"])/2.4)
	}
	if (P["PT"] == "")
		load_rfp("PT", P["PW"] * 0.8)
	if (P["BL"] == "")
		load_rfp("BL", round_to((NOM["PP"] * int(P["N"]/2+0.5)), 0.1))


	if (P["PG"] == "") {
		MAX["PG"] = MAX["PE"] - 2*MIN["PC"]
		MIN["PG"] = MIN["PE"] - 2*MAX["PC"]
		mktol("PG")
	}
	else if (P["PC"] == "") {
		MAX["PC"] = (MAX[PE] - MIN["PG"]) / 2
		MIN["PC"] = (MIN[PE] - MAX["PG"]) / 2
		mktol("PC")
	}

# improvise missing component drawing data
	if (P["BW"] == "")
		load_rfp("BW", round_to(NOM["PG"] * 0.825, 0.1))

#print "BODY: ", NOM["BL"], NOM["BW"] > "/dev/stderr"

	ipc_init_gentol()
	so_pinpat(PINPAT, P["N"])

	# set up and call draw function
	D["pitch"] = NOM["PP"]
	D["pad_spacing"] = NOM["PRP"]
	D["pad_length"] = NOM["PL"]
	D["pad_width"] = NOM["PW"]

	D["lead_width"] = NOM["PT"]
	D["lead_width_max"] = MAX["PT"]
	D["lead_extent"] = NOM["PE"]
	D["lead_gap"] = NOM["PG"]
	D["body_width"] = NOM["BW"]
	D["body_width_max"] = MAX["BW"]
	D["body_length"] = NOM["BL"]
	D["body_length_max"] = MAX["BL"]
	D["courtyard_extent"] = NOM["CYE"]
	D["cpad_length"] = NOM["CPL"]
	D["cpad_width"] = NOM["CPW"]

	centerpad_setup(D, P)

	gullwing2_draw(D, PINPAT)
}
